% FILENAME:     MC2006 OCT 16.m
% DESCRIPTION:  Double Pendulum Parameters
% VERSION NO:   MC file version 7


% NOTE:         filename format RM<year><month><date>.m
%               version number to be incremented plus date changed

%****************************************************
%% Written by Calum Iain Torrie 7/98        
%% modified by K.A. Strain 6/99             
%% modified BY CALUM TORRIE DEC 2001                                                    version 1
%% Norna/CIT - summer 2002                                                              version 2
%% CIT - 01/Sept/2002                                                                   version 3
%% CIT - 29/Apr/2003                                                                    version 4
%% CIT - 01/May2003 (included masses and d's for a particular suspended suspension      version 5
%% CIT - 25/SEPT/2003 (updated m1 and the d's) default CP                               version 6
%% Chris Cueva - 16/Oct/2006 triple pendulum model reduced to a double pendulum         version 7

%% various updates by Norna Robertson as OMC design developed. 
%% Latest update 15th April 2007
%****************************************************

outputmodecleaner = 1; % 1 to load parameters for output mode cleaner


pend.pendulum_model = 'double_pendulum'; % pend.pendulum_model='single_pendulum' reduces the double pendulum model to a single pendulum model
                                         % pend.pendulum_model='double_pendulum' to run the model as a double pendulum
% To reduce the double pendulum model to a single pendulum model the
% parameters are changed in the file doublep.m and k2 is set to zero 
% in the file ssmake_doublep.m


g	=9.81;
 % represents small loss
 bd=0.0;


 % Parameters for Output Mode Cleaner
if outputmodecleaner 
   
%m1 = 20; % UPPER MASS (rectangle) = ux*uy*uz*den1
%den1 = 1000;
%den1 = 2700; % density (aluminium)
%den1 = 7800; % density (steel)
%ux = 0.27; 
%uy = 0.442;
%uz = m1/(ux*uy*den1); % m1=20,ux=0.2,uy=0.442,den1=2700, uz~0.084
                      % m1=20,ux=0.27,uy=0.442,den1=2700, uz~0.062
% moments of inertia
%I1x = m1*(uy^2+uz^2)/12; % moment of inertia (sideways roll)
%I1y = m1*(uz^2+ux^2)/12; % moment of inertia (longitudinal tilt)
%I1z = m1*(uy^2+ux^2)/12; % moment of inertia (rotation)

% IMC parameters entered Nov 06
%m1 = 3.125; %updated from info in e-mail from CIT 14 Oct 04 ref LIGO-T030135-04
 %I1x =    0.0238;   
 %I1y =    0.0024;
 %I1z =    0.0238;
 
 %actual parameters from solidworks model, from Chris Echols 15 Mar 2007
 %m1 = 2.85; 
 %I1x =    0.0153;   % this is z direction in Chris's solidworks
 %I1x =    0.02; try this to see effect
 
 %I1y =    0.00259; % this is x direction in Chris's solidworks - along long direction of bench
 %I1z =    0.0151;  % this is y direction in Chris's solidworks (vertical)
 
 %revised numbers for as built mass including info from measurements of the
 %mass 26th June 2007
  %m1 = 2.773; 
 %I1x =    0.0154;   % this is z direction in Chris's solidworks
 %I1y =    0.00278; % this is x direction in Chris's solidworks - along long direction of bench
 %I1z =    0.0148;  % this is y direction in Chris's solidworks (vertical)
 
 % info from e-mail from Chris Echols 8 April 2008 
 %NB this is for LHO OMC - small mods resulting in slightly reduced mass
 %compared the LLO OMC
 %Note added 25 April 08 - the I's here are not taken at C of M - this
 %needs updating with correct info
   %m1 = 2.736; 
 %I1x =    0.0152;   % this is z direction in Chris's solidworks
 %I1y =    0.00282; % this is x direction in Chris's solidworks - along long direction of bench
 %I1z =    0.0147;  % this is y direction in Chris's solidworks (vertical)
 
  % this is the LLO OMC as from Chris e-mail 25 April 2008
  %NB I's taken at centre of mass and aligned w/output coord system
 m1 = 2.754; 
 I1x =    0.0150;   % this is z direction in Chris's solidworks
 I1y =    0.00248; % this is x direction in Chris's solidworks - along long direction of bench
 I1z =    0.0148;  % this is y direction in Chris's solidworks (vertical)
 

 
%******************************************************************
%m2 = 40; % LOWER MASS (square) = ix*iy*iz*den2 
%den2 = 1000;
%den2 = 2700; % density (aluminium)
%den2 = 7800; % density (steel)
%ix = 0.5; 
%iy = 0.5;
%iz = m2/(ix*iy*den2); % m2-40,ix=iy=.5,den2=1000, iz~0.16
                      % m2=40,ix=iy=0.5,den2=2700, iz~0.059 
                      

%New values Nov 06
%m2 = 6; % LOWER MASS (square) = ix*iy*iz*den2 
%den2 = 2200; %silica density
%den2 = 2700; % density (aluminium)????????????????
%den2 = 7800; % density (steel)
%ix = 0.15; 
%iy = 0.45;
%iz = 0.04; 

%iz = 0.0381; %revised size Mar 2007

%I2x = m2*(iy^2+iz^2)/12; % moment of inertia (sideways roll)
%I2y = m2*(iz^2+ix^2)/12; % moment of inertia (longitudinal tilt)
%I2z = m2*(iy^2+ix^2)/12; % moment of inertia (rotation) 


%Optical bench values from Sam Waldman as posted on OMC WIKI Modified 2007-04-15 19:28:16 GMT  
%m2 = 6.33;
%I2x = 0.118 ; % moment of inertia (sideways roll)
%I2y = 0.0143; % moment of inertia (longitudinal tilt)
%I2z = 0.129; % moment of inertia (rotation)

% optical bench with counterweight of 500 gm as modelled by Chris

%m2 = 7.30;

%I2x = 0.150 ; % moment of inertia (sideways roll)
%I2y = 0.0193; % moment of inertia (longitudinal tilt)
%I2z = 0.161; % moment of inertia (rotation)

 % info from (second) e-mail from Chris Echols 8 April 2008  -current optical
 % bench for LLO (I's taken at centre of mass)
m2 = 6.895;
I2x = 0.139 ; % moment of inertia (sideways roll)
I2y = 0.0164; % moment of inertia (longitudinal tilt)
I2z = 0.150; % moment of inertia (rotation)

% Current metal bench without added mass - info from Chris 8th June 2007
% coordinate system needs to be confirmed
%m2 = 6.17;
%I2x = 0.109 ; % moment of inertia (sideways roll)
%I2y = 0.0128; % moment of inertia (longitudinal tilt)
%I2z = 0.120; % moment of inertia (rotation)

 % revised values from CAD model with rods for supporting wires and added
 % masses on top June 26th 2007
 %m2 = 6.417;
%I2x = 0.118 ; % moment of inertia (sideways roll)
%I2y = 0.0133; % moment of inertia (longitudinal tilt)
%I2z = 0.130; % moment of inertia (rotation)
 
%******************************************************************
%d0 = 0.001;
%d0 = 0.001; % height of upper wire break-off (above c.of m. upper mass)
%d1 = 0.001; % height of lower wire break-off (below c.of m. upper mass)

%alternate taking into account larger flexure length/thicker wire Feb 07
%d0 = 0.002; % height of upper wire break-off (above c.of m. upper mass)
%d1 = 0.0015; % height of lower wire break-off (below c.of m. upper mass)



%d2 = 0.001; % height of lower wire break-off (above c.of m. of lower mass)

%d2 = 0.003; % value chosen for optical bench design ref Sam Waldman April2007

%include flexure lengths for wires (14 thou diam upper  flex = 1.9 mm, 
%8 thou lower flex = 1.1 mm) April 30 2007
%d0 = 0.0029;
%d1 = 0.0021;

%d2 = 0.0041; %this is estimate for optical bench incl flexure
d2 = 0.0030; %revised estimate for optical bench using data from Chris from CAD model 9th April 2008 
% see my notebook p92: 1.88 mm physical distance plus 1.1 mm flexure length

%d2 = 0.0018; % this is close to value for metal bench June 07, from Chris info plus flexure

% updated values from measurements in situ and comparing to CAD model June
% 26th 2007
d0 = 0.0018;  %(-0.13 plus 1.9 mm)

%d1 = 0.0018;  % (1.13 + 1.1 mm) from meaurements in situ by Alejandro plus CAD info
% note added on 19th April 2008 -looks like d1 should have been 0.0022 here

%d2 = 0.0012; % (0.1 from CAD plus 1.1 mm)

%d1 = 0.0088; %add 7mm on for heavier bench Nov 8th 2007

d1 = 0.0015;   % 28th April 2008 see notebook pages 80, 81, 128, 129,130 using info from Chris
% flat blade would give physical break-off at 0.55 mm +flexure length of 1.1mm 
% Hence total would be 1.65 mm if blade flat. We have used angled clamps so
% blades bow up and down. From Tobin's pictures (for 3 of the blades) it appears the blade tips are
% on average above where the flat blade would lie by 0.4 mm (a little surprising)and total d1 is 0.4 plus
% 1.1 = 1.5 mm. Error on this of order 0.5 mm I would estimate.


%******************************************************************
% X direction separation
su = 0;
%su = 0.08; % 1/2 separation of upper wires
%si = 0.103/2; % 1/2 separation of lower wires
si = 0.15/2; %

si=0.06/2; %alternative to reduce higher pitch frequency jan 2007
%******************************************************************
% Y direction separation
%n0 = 0.118/2; % 1/2 separation of upper wires at suspension point
n0 = 0.144/2;
n1 = 0.144/2; % 1/2 separation of upper wires at upper mass
n2 = 0.27/2; % 1/2 separation of lower wires at upper mass
% wires 20% of length away from each = 0.2x0.145 = 0.029 from ends 
n3 = 0.27/2; % 1/2 separation of lower wires at lower mass
%**********************************************
nw1 = 2; % number of wires per stage (2 or 4)
nw2 = 4; 
%******************************************************************
r1 = 1.5e-4; % radius of upper wire
% use wire as in IMC Feb 2007
r1 = 1.78e-4; % 14 thou diameter
r = sqrt((m1+m2)*g/(pi*(6.666e8)*nw1)); 
if r>r1,r1=r;, end; % want stress on upper wires to be less than 6.666x10^8

r2 = 0.85e-4; % radius of lower wire
% use wire as in IMC Feb 2007
r2 = 1.02e-4; % 8 thou diameter

%r2 = 5e-4; % radius of lower wire try this - 1mm diameter ( possible drum wire)

r = sqrt(m2*g/(pi*(6.666e8)*nw2)); 
if r>r2,r2=r;, end; % want stress on lower wires to be less than 6.666x10^8
%******************************************************************
Y1 = 2.12e11; % Youngs Modulus of upper steel wire  
Y2 = 2.12e11; % Youngs Modulus of lower steel wire       
%******************************************************************
l1 = 0.25; %
l2 = 0.25; % 

%l2 = 0.27; % as built June 26th 2007

%l1 = 0.20; %try shorter for upside down bench Nov 06
%l2 = 0.20; % 

%******************************************************************
% - uncoupled mode frequency- the frequency observed for a cantilever in a
% particular stage supporting only the mass of that stage

% In other words ufc1 is the frequency mass 1 will oscillate at if
% only supported by the cantilevers

%ufc1 =1.9185; % frequency = ufc1 = sqrt(number-of-cantilevers*kc1/m)/(2*pi) 
              % where kc1 is the spring constant of ONE of the cantilevers
              % opt(10,30,8e8,.4,.1)
%ufc1 = 2.4907; % opt(10,30,8e8,.23,.18)
ufc1 = 2.3; % using EXCEL program BLADEsr,shape factor 1.3 and 25 cm by 4 cm by 1.5 mm (MC blade size)

ufc1=2.38;     %updated 11 July 2007, using measurements of one of the blades from Calum    

%ufc1 = 2.57; 
%ufc2 = 0; % uncoupled mode frequency of cantilever stage(=0 for no cantilevers)
ufc2 = 2.3; % input modecleaner lower blades with 6kg on them NAR DEC 06
ufc2 = 2.21; %updated 11 July 2007, using measurements of 2 of the blades from Calum   
ufc2 = 2.07; % updated 9th Nov 2007 - mass now estimated at 7.3 kg c.f. 6.4 kg used 11 July 07
ufc2 = 2.13; %updated 9th April 2008 - mass now 6.9 kg

%******************************************************************
% in X-direction wires must be vertical
s0 = su;s1 = su;
s2 = si;s3 = si;
%******************************************************************
end

if strcmp('single_pendulum',pend.pendulum_model)
    m2 = 1e-24;
    l2 = 1e24;
    I2x = 1e-12; % moment of inertia (sideways roll)
    I2y = 1e-12; % moment of inertia (longitudinal tilt)
    I2z = 1e-12; % moment of inertia (rotation)    
end


% update variable pend
pend.m1 = m1;
%pend.ux = ux;
%pend.uy = uy;
%pend.uz = uz;
pend.I1x = I1x;
pend.I1y = I1y;
pend.I1z = I1z;

pend.m2 = m2;
%pend.ix = ix;
%pend.iy = iy;
%pend.iz = iz;
pend.I2x = I2x;
pend.I2y = I2y;
pend.I2z = I2z;

pend.l1 = l1;
pend.l2 = l2;

pend.nw1 = nw1;
pend.nw2 = nw2;	

pend.r1 = r1;
pend.r2 = r2;
pend.Y1 = Y1;
pend.Y2 = Y2;

pend.ufc1 = ufc1;	
pend.ufc2 = ufc2;

pend.d0 = d0;
pend.d1 = d1;
pend.d2 = d2;

pend.su = su;
pend.si = si;

pend.n0 = n0;
pend.n1 = n1;
pend.n2 = n2;
pend.n3 = n3;


%% coordinates x = longitudinal = u_LIGO roll about this axis
%%             y = transverse   = v_LIGO pitch about this axis
%%             z = vertical     = w_LIGO yaw about this axis

%IMPORTANT FOR REFERENCE ONLY!!!

% these are gains for the IMC - use this as a basis for the OMC NAR Nov 06


%Gain triangles in pendn.m


%Gain triangle = (leverarm)^2 * (no. of coils) * gain


%***Note that gains are linked in different directions due to common coils as below*****
%***If gains in one channel only need to be changed then leverarm can be used***********

% gain 0.06

%gainzrtrl =gain;       % vertical, z, pitch, rt, roll rl (coils on top of upper mass)
%gaint   = gain.*2;     % transverse, t (coil on one end of upper mass)
%gainlrz = gain;                % longitudinal, l, yaw, rz (coils on long rear side of upper mass)


%long   = (1)^2    *  2 * gainlrz    = 0.12
%pitch  = (0.03)^2 *  2 * gainzrtrl    = 1.08e-4
%vert   = (1)^2    *  3 * gainzrtrl    = 0.18
%yaw    = (0.08)^2 *  2 * gainlrz    = 7.68e-4
%trans  = (1)^2    *  1 * gaint   = 0.12
%roll   = (0.06)^2 *  3 * gainzrtrl    = 6.48e-4


% revised set of gains - using leverarms from Chris Echols Jan 2007 
%YAW: 57 mm
%ROLL: 100 mm
%PITCH: 30 mm
%long   = (1)^2    *  2 * gainlrz    = 0.12
%pitch  = (0.03)^2 *  2 * gainzrtrl    = 1.08e-4
%vert   = (1)^2    *  3 * gainzrtrl    = 0.18
%yaw    = (0.057)^2 *  2 * gainlrz    = 3.90e-4
%trans  = (1)^2    *  1 * gaint   = 0.12
%roll   = (0.1)^2 *  3 * gainzrtrl    = 1.8e-3




%**************************************************************************************

%VIEWER PREFERENCES (under edit on LTI viewer)

%UNITS
%Frequency in Hz using Log scale
%Magnitude in absolute using log scale
%Phase in degrees


%TIME VECTOR
%[0:0.01:50]

%FREQUENCY VECTOR
%logspace(-0.5,1.5,500)

%****************************************

% EXTRACTING DATA FROM TRANSFER FUNCTIONS and IMPULSE RESPONSE

%TRANSFER FUNCTION
% File export - export to workspace
%sys = tf(pendn_1(1,1));  [or equivalent i.e.sys = tf(pendn_1(6,10));]
%damp(sys);

%IMPULSE RESPONSE
% right click in screen and select properties - characteristics - select settling time
%set settling time 36.7% (1/e)
